markuptools.Markup
==================

.. inheritance-diagram:: abjad.tools.markuptools.Markup.Markup.Markup
   :private-bases:

.. autoclass:: abjad.tools.markuptools.Markup.Markup.Markup

Read-only Properties
--------------------

.. autoattribute:: abjad.tools.markuptools.Markup.Markup.Markup.contents

.. autoattribute:: abjad.tools.markuptools.Markup.Markup.Markup.indented_lilypond_format

.. autoattribute:: abjad.tools.markuptools.Markup.Markup.Markup.lilypond_format

.. autoattribute:: abjad.tools.markuptools.Markup.Markup.Markup.markup_name

.. autoattribute:: abjad.tools.markuptools.Markup.Markup.Markup.start_component

    Inherited from :py:class:`marktools.Mark <abjad.tools.marktools.Mark.Mark.Mark>`

.. autoattribute:: abjad.tools.markuptools.Markup.Markup.Markup.storage_format

    Inherited from :py:class:`abctools.AbjadObject <abjad.tools.abctools.AbjadObject.AbjadObject.AbjadObject>`

Read/write Properties
---------------------

.. autoattribute:: abjad.tools.markuptools.Markup.Markup.Markup.direction

    Inherited from :py:class:`marktools.DirectedMark <abjad.tools.marktools.DirectedMark.DirectedMark.DirectedMark>`

Methods
-------

.. automethod:: abjad.tools.markuptools.Markup.Markup.Markup.attach

    Inherited from :py:class:`marktools.Mark <abjad.tools.marktools.Mark.Mark.Mark>`

.. automethod:: abjad.tools.markuptools.Markup.Markup.Markup.detach

    Inherited from :py:class:`marktools.Mark <abjad.tools.marktools.Mark.Mark.Mark>`

Special Methods
---------------

.. automethod:: abjad.tools.markuptools.Markup.Markup.Markup.__call__

    Inherited from :py:class:`marktools.Mark <abjad.tools.marktools.Mark.Mark.Mark>`

.. automethod:: abjad.tools.markuptools.Markup.Markup.Markup.__delattr__

    Inherited from :py:class:`marktools.Mark <abjad.tools.marktools.Mark.Mark.Mark>`

.. automethod:: abjad.tools.markuptools.Markup.Markup.Markup.__eq__

.. automethod:: abjad.tools.markuptools.Markup.Markup.Markup.__ge__

    Inherited from :py:class:`abctools.AbjadObject <abjad.tools.abctools.AbjadObject.AbjadObject.AbjadObject>`

.. automethod:: abjad.tools.markuptools.Markup.Markup.Markup.__gt__

    Inherited from :py:class:`abctools.AbjadObject <abjad.tools.abctools.AbjadObject.AbjadObject.AbjadObject>`

.. automethod:: abjad.tools.markuptools.Markup.Markup.Markup.__hash__

.. automethod:: abjad.tools.markuptools.Markup.Markup.Markup.__le__

    Inherited from :py:class:`abctools.AbjadObject <abjad.tools.abctools.AbjadObject.AbjadObject.AbjadObject>`

.. automethod:: abjad.tools.markuptools.Markup.Markup.Markup.__lt__

    Inherited from :py:class:`abctools.AbjadObject <abjad.tools.abctools.AbjadObject.AbjadObject.AbjadObject>`

.. automethod:: abjad.tools.markuptools.Markup.Markup.Markup.__ne__

.. automethod:: abjad.tools.markuptools.Markup.Markup.Markup.__repr__

    Inherited from :py:class:`marktools.Mark <abjad.tools.marktools.Mark.Mark.Mark>`

.. automethod:: abjad.tools.markuptools.Markup.Markup.Markup.__str__
